@@ -1,3 +1,5 @@
+import random
+import string
 from functools import wraps
 
 
@@ -11,3 +13,7 @@ def as_list(func):
 
 def sanitize_email(email):
     return email.replace("_", r"\_")
+
+
+def rand_id():
+    return "".join(random.choices(string.ascii_uppercase, k=32))
